"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var path_1 = tslib_1.__importDefault(require("path"));
var ora_1 = tslib_1.__importDefault(require("ora"));
var fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
var models_1 = require("../../shared/models");
var add_1 = require("../../setup/add");
var package_const_1 = require("../../shared/constants/package.const");
var utils_1 = require("../../shared/utils");
var messages_1 = require("../../shared/messages");
var featureOptions = Object.keys(add_1.featureTemplates);
exports.addBinCommand = function (prog) {
    prog
        .command('add <feature>')
        .describe("Add available feature.\n  Currently available choices: [" + featureOptions.join(', ') + "]")
        .example('add playground')
        .action(function (featureName) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
        var _a, generating, wrongWorkspace, failed, successful, invalidTemplate, exists, script, bootSpinner, currentPath, packageJsonPath, packageJson, err_1, updatedScripts, err_2;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    _a = new messages_1.FeatureMessages(featureName), generating = _a.generating, wrongWorkspace = _a.wrongWorkspace, failed = _a.failed, successful = _a.successful, invalidTemplate = _a.invalidTemplate, exists = _a.exists, script = _a.script;
                    bootSpinner = ora_1.default(generating());
                    return [4 /*yield*/, fs_extra_1.default.realpath(process.cwd())];
                case 1:
                    currentPath = _b.sent();
                    packageJsonPath = path_1.default.resolve(currentPath, package_const_1.PACKAGE_JSON);
                    packageJson = {};
                    _b.label = 2;
                case 2:
                    _b.trys.push([2, 4, , 5]);
                    return [4 /*yield*/, fs_extra_1.default.readJSON(packageJsonPath)];
                case 3:
                    packageJson = _b.sent();
                    if (!packageJson.workspace) {
                        throw new models_1.WrongWorkspaceError(wrongWorkspace());
                    }
                    return [3 /*break*/, 5];
                case 4:
                    err_1 = _b.sent();
                    bootSpinner.fail(failed());
                    if (err_1.isWrongWorkspace) {
                        console.log(utils_1.error(err_1));
                    }
                    else {
                        console.log(utils_1.error(new models_1.NoPackageJsonError(script())));
                        utils_1.logError(err_1);
                    }
                    process.exit(1);
                    return [3 /*break*/, 5];
                case 5:
                    if (!featureOptions.includes(featureName)) {
                        bootSpinner.fail(failed());
                        console.log(utils_1.error(invalidTemplate()));
                        process.exit(1);
                    }
                    bootSpinner.start();
                    _b.label = 6;
                case 6:
                    _b.trys.push([6, 9, , 10]);
                    return [4 /*yield*/, fs_extra_1.default.copy(path_1.default.resolve(__dirname, "../../../../templates/add/" + featureName), path_1.default.resolve(currentPath, add_1.featureTemplates[featureName].path), { overwrite: false, errorOnExist: true })];
                case 7:
                    _b.sent();
                    updatedScripts = tslib_1.__assign(tslib_1.__assign({}, packageJson.scripts), add_1.featureTemplates[featureName].scripts);
                    return [4 /*yield*/, fs_extra_1.default.outputJSON(packageJsonPath, tslib_1.__assign(tslib_1.__assign({}, packageJson), { scripts: updatedScripts }))];
                case 8:
                    _b.sent();
                    bootSpinner.succeed(successful());
                    return [3 /*break*/, 10];
                case 9:
                    err_2 = _b.sent();
                    bootSpinner.fail(failed());
                    if (err_2.toString().includes('already exists')) {
                        console.log(exists());
                    }
                    utils_1.logError(err_2);
                    process.exit(1);
                    return [3 /*break*/, 10];
                case 10: return [2 /*return*/];
            }
        });
    }); });
};
