"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable sonarjs/no-duplicate-string */
var package_utils_1 = require("./package.utils");
describe('[CLI.Utils] Package', function () {
    describe('findWorkspacePackages', function () {
        test('should return empty array when there is no workspaces property', function () {
            expect(package_utils_1.findWorkspacePackages(undefined)).toEqual([]);
        });
        test('should return empty array when there is no packages inside workspaces config', function () {
            expect(package_utils_1.findWorkspacePackages({ packages: undefined })).toEqual([]);
        });
        test('should return empty array when workspaces property is empty array', function () {
            expect(package_utils_1.findWorkspacePackages([])).toEqual([]);
        });
        test('should return empty array when workspaces packages property is empty array', function () {
            expect(package_utils_1.findWorkspacePackages({ packages: [] })).toEqual([]);
        });
        test('should return packages when workspaces property has them', function () {
            expect(package_utils_1.findWorkspacePackages(['a', 'b'])).toEqual(['a', 'b']);
        });
        test('should return packages when workspaces packages property has them', function () {
            expect(package_utils_1.findWorkspacePackages({ packages: ['a', 'b'] })).toEqual([
                'a',
                'b'
            ]);
        });
    });
    describe('findPackageSetupPath', function () {
        test('should return default path with input of empty packages', function () {
            expect(package_utils_1.findPackageSetupPath([])).toBe('packages');
        });
        test('should return default path with input of separate packages', function () {
            expect(package_utils_1.findPackageSetupPath(['/a', 'b', 'c/', '/d/'])).toBe('packages');
        });
        test('should return path when there is one wildcard', function () {
            expect(package_utils_1.findPackageSetupPath(['workspaces/*'])).toBe('workspaces');
        });
        test('should return path when there is only one wildcard', function () {
            expect(package_utils_1.findPackageSetupPath(['a', 'workspaces/*', 'b'])).toBe('workspaces');
        });
        test('should return path of the last wildcard', function () {
            expect(package_utils_1.findPackageSetupPath(['a', 'otherPackages/*', 'c', 'workspaces/*', 'b'])).toBe('workspaces');
        });
    });
});
